@@ -71,5 +71,5 @@ def areasRefinado(modeloL,areas):
     a = []
     for e in modeloL.elementos:
         Ue = areas[np.ix_(e.gdl)]
-        a.append(np.average(Ue))
+        a.append(np.min(Ue))
     return a
\ No newline at end of file
